************************************************************************
* File (nc_br_1414_2020.f) created on Fri Dec  5 00:38:31 MSK 2008.
************************************************************************
* This is the FORTRAN module (nc_bo_1414_2020) to calculate EW
* integrated Born cross section for dn + dn -> ta + ta process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_bo_1414_2020 (s,born)
      implicit none!
      include 's2n_declare.h'

      real*8 v1z,v2z,vaz
      real*8 v0s,vas
      real*8 kappaz
      complex*16 chizs,chizsc
      real*8 betastata,ibetastata

      cmz2 = mz2

      kappaz   = gf*rzm2/(dsqrt(2d0)*8d0*pi)/alpha
      chizs    = 4d0*kappaz*s/(s-cmz2)
      chizsc   = dconjg(chizs)

      v1z = vdn*vta
      v2z = (vdn**2+adn**2)*(vta**2+ata**2)
      vaz = (vdn**2+adn**2)*(vta**2-ata**2)

      v0s =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*v2z
      vas =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*vaz

      betastata = sqrt(1d0-4d0*mta**2/s)
      ibetastata = 1d0/betastata

      born=
     & +v0s*betastata*pi*alpha**2*(4d0/3*mta**2/s**2)
     & +v0s*betastata**3*pi*alpha**2*(4d0/9/s)
     & +vas*betastata*pi*alpha**2*(4d0/3*mta**2/s**2)

      born = born*conhc

      return
      end
************************************************************************
* This is the FORTRAN module (nc_br_1414_2020) to calculate EW Born
* cross section and soft photon Bremsstrahlung
* for dn + dn -> ta + ta process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_br_1414_2020 (qs,ts,us,born,soft,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 lnlaom,cpl,cmi
      real*8 a0s,v0s,vaz
      real*8 a1z,a2z,v1z,v2z,vas
      real*8 softisr,softfsr,softifi
      real*8 kappaz
      complex*16 chizs,chizsc,chizspr,chizsprc
      real*8 betastata,ibetastata
      real*8 jintqstata

      cmz2 = mz2
      s = -qs
      t = -ts
      u = -us

      cosf = (t-u)/s/betaf
      sinf = dsqrt(1d0-cosf**2)

      cpl = (1+cosf)/2d0
      cmi = (1-cosf)/2d0

      kappaz   = gf*rzm2/(dsqrt(2d0)*8d0*pi)/alpha
      chizs    = 4d0*kappaz*s/(s-cmz2)
      chizsc   = dconjg(chizs)

      a1z = adn*ata
      a2z = 4d0*vdn*adn*vta*ata
      v1z = vdn*vta
      v2z = (vdn**2+adn**2)*(vta**2+ata**2)
      vaz = (vdn**2+adn**2)*(vta**2-ata**2)

      v0s =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*v2z
      a0s =
     & +qdn*qta*(chizs+chizsc)*a1z
     & +chizs*chizsc*a2z
      vas =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*vaz

      betastata = sqrt(1d0-4d0*mta**2/s)
      ibetastata = 1d0/betastata

      born=
     & +a0s*betastata**2*pi*alpha**2*(1d0/3*cosf/s)
     & +v0s*betastata*pi*alpha**2*(2d0/3*mta**2/s**2)
     & +v0s*betastata**3*pi*alpha**2*(1d0/6*(1+cosf**2)/s)
     & +vas*betastata*pi*alpha**2*(2d0/3*mta**2/s**2)

      born = born*conhc
      virt = 0d0
      soft = 0d0
      hard = 0d0

      if (iborn.eq.1) return

      lnlaom = log(4d0*omega**2/tlmu2)
      jintqstata = log((1d0-betastata)/(1d0+betastata))

      softisr=
     & +born*pi*alpha*qdn**2*(-1d0/3)
     & +lnlaom*born/pi*alpha*qdn**2*(-1)
     & +lnlaom*log(mdn**2/s)*born/pi*alpha*qdn**2*(-1)
     & +log(mdn**2/s)*born/pi*alpha*qdn**2*(-1)
     & +log(mdn**2/s)**2*born/pi*alpha*qdn**2*(-1d0/2)

      softfsr=
     & +ibetastata*born/pi*alpha*qta**2*(-jintqstata-1d0/2*jintqstata**2
     & +jintqstata**2*mta**2/s)
     & +ibetastata*born*pi*alpha*qta**2*(-1d0/3+2d0/3*mta**2/s)
     & +ibetastata*lnlaom*born/pi*alpha*qta**2*(-jintqstata+2*jintqstata
     & *mta**2/s)
     & +ibetastata*log(2-2/(1+betastata))*born/pi*alpha*qta**2*(2*jintqs
     & tata-4*jintqstata*mta**2/s)
     & +ibetastata*ddilog(-1+2/(1+betastata))*born/pi*alpha*qta**2*(2-4*
     & mta**2/s)
     & +lnlaom*born/pi*alpha*qta**2*(-1)

      softifi=
     & +lnlaom*log(1/(us+mta**2)*ts+1/(us+mta**2)*mta**2)*born/pi*alpha*
     & qdn*qta*(2)
     & +log(1+1d0/qs/ts*mta**4+1d0/qs*ts+2/qs*mta**2)*log(-1/(2*ts*mta**
     & 2+ts**2+mta**4)*qs*ts)*born/pi*alpha*qdn*qta*(2)
     & +log(1+1d0/qs/us*mta**4+1d0/qs*us+2/qs*mta**2)*log(-1/(2*us*mta**
     & 2+us**2+mta**4)*qs*us)*born/pi*alpha*qdn*qta*(-2)
     & +log(1-2/(1+betastata)/(ts+mta**2)*mta**2)*born/pi*alpha*qdn*qta*
     & (2*jintqstata)
     & +log(1-2/(1+betastata)/(ts+mta**2)*mta**2)**2*born/pi*alpha*qdn*q
     & ta*(-1)
     & +log(1-2/(1+betastata)/(us+mta**2)*mta**2)*born/pi*alpha*qdn*qta*
     & (-2*jintqstata)
     & +log(1-2/(1+betastata)/(us+mta**2)*mta**2)**2*born/pi*alpha*qdn*q
     & ta*(1)
     & +log(-1/(2*ts*mta**2+ts**2+mta**4)*qs*ts)**2*born/pi*alpha*qdn*qt
     & a*(1)
     & +log(-1/(2*us*mta**2+us**2+mta**4)*qs*us)**2*born/pi*alpha*qdn*qt
     & a*(-1)
     & +ddilog(1-2/(1+betastata)/(ts+mta**2)*ts)*born/pi*alpha*qdn*qta*(
     & 2)
     & +ddilog(1-2/(1+betastata)/(us+mta**2)*us)*born/pi*alpha*qdn*qta*(
     & -2)
     & +ddilog(-1d0/qs/ts*mta**4-1d0/qs*ts-2/qs*mta**2)*born/pi*alpha*qd
     & n*qta*(-2)
     & +ddilog(-1d0/qs/us*mta**4-1d0/qs*us-2/qs*mta**2)*born/pi*alpha*qd
     & n*qta*(2)
     & +ddilog(-1/(ts-mta**2+betastata*ts+betastata*mta**2)*ts-1/(ts-mta
     & **2+betastata*ts+betastata*mta**2)*mta**2+1/(ts-mta**2+betastata*
     & ts+betastata*mta**2)*betastata*ts+1/(ts-mta**2+betastata*ts+betas
     & tata*mta**2)*betastata*mta**2)*born/pi*alpha*qdn*qta*(-2)
     & +ddilog(-1/(us-mta**2+betastata*us+betastata*mta**2)*us-1/(us-mta
     & **2+betastata*us+betastata*mta**2)*mta**2+1/(us-mta**2+betastata*
     & us+betastata*mta**2)*betastata*us+1/(us-mta**2+betastata*us+betas
     & tata*mta**2)*betastata*mta**2)*born/pi*alpha*qdn*qta*(2)

      if (iqed.eq.1) then
         soft = softisr+softfsr+softifi
      elseif(iqed.eq.2) then
         soft = softisr
      elseif(iqed.eq.3) then
         soft = softifi
      elseif(iqed.eq.4) then
         soft = softfsr
      elseif(iqed.eq.5) then
         soft = softifi+softfsr
      endif

      return
      end
************************************************************************
* This is the FORTRAN module (nc_ha_1414_2020_1spr) to calculate hard
* photon Bremsstrahlung for dn + dn -> ta + ta process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_ha_1414_2020_1spr (s,spr,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 kappaz,coef,sqs
      real*8 betasdndn,betasprtata
      real*8 jintsdndn,jintsprtata,ln1sdn,ln1bsprta
      real*8 a1z,a2z,v1z,v2z,vaz
      real*8 v0s,vas,v0spr,vaspr,a1sspr,a2sspr
      complex*16 chizs,chizsc,chizspr,chizsprc

      cmz2 = mz2

      kappaz   = gf*rzm2/(dsqrt(2d0)*8d0*pi)/alpha
      chizs    = 4d0*kappaz*s/(s-cmz2)
      chizsc   = dconjg(chizs)
      chizspr  = 4d0*kappaz*spr/(spr-cmz2)
      chizsprc = dconjg(chizspr)

      a1z = adn*ata
      a2z = 4d0*vdn*adn*vta*ata
      v1z = vdn*vta
      v2z = (vdn**2+adn**2)*(vta**2+ata**2)
      vaz = (vdn**2+adn**2)*(vta**2-ata**2)

      v0s =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*v2z
      vas =
     & +qdn**2*qta**2
     & +qdn*qta*(chizs+chizsc)*v1z
     & +chizs*chizsc*vaz
      v0spr =
     & +qdn**2*qta**2
     & +qdn*qta*(chizspr+chizsprc)*v1z
     & +chizspr*chizsprc*v2z
      vaspr =
     & +qdn**2*qta**2
     & +qdn*qta*(chizspr+chizsprc)*v1z
     & +chizspr*chizsprc*vaz
      a1sspr =
     & -(chizs+chizsc-chizspr-chizsprc)*a1z
      a2sspr =
     & +qdn*qta*(chizs+chizsc+chizspr+chizsprc)*a1z
     & +(chizs*chizsprc+chizsc*chizspr)*a2z

      betasdndn = dsqrt(1d0-4d0*rdnm2/s)
      jintsdndn = dlog((1d0-betasdndn)/(1d0+betasdndn))
      ln1sdn    = -jintsdndn-1d0
      betasprtata = dsqrt(1d0-4d0*rtam2/spr)
      jintsprtata = dlog((1d0-betasprtata)/(1d0+betasprtata))
      ln1bsprta   = -jintsprtata-betasprtata

      hard=
     & +v0s*(s**2+spr**2)*alpha**3*qta**2/(s-spr)*(-4d0/9*jintsprtata*mt
     & a**2/s**4+4d0/9*ln1bsprta/s**3)
     & +v0s*alpha**3*qta**2*spr/(s-spr)*(16d0/9*jintsprtata*mta**2/s**3)
     & +v0s*alpha**3*qta**2/(s-spr)*(16d0/9*jintsprtata*mta**2/s**2-16d0
     & /9*jintsprtata*mta**4/s**3)
     & +v0s*betasprtata*alpha**3*qta**2*spr/(s-spr)*(8d0/9*mta**2/s**3)
     & +v0spr*betasprtata*(s**2+spr**2)*alpha**3*qdn**2/spr**2/(s-spr)*(
     & -4d0/9*ln1sdn*mta**2/s**2)
     & +v0spr*betasprtata*(s**2+spr**2)*alpha**3*qdn**2/spr/(s-spr)*(4d0
     & /9*ln1sdn/s**2)
     & +a2sspr*(s+spr)**2*alpha**3*qdn*qta/spr/(s-spr)*(-2d0/3*jintsprta
     & ta*mta**2/s**3)
     & +a2sspr*betasprtata*(s+spr)*alpha**3*qdn*qta/(s-spr)*(-2d0/3/s**2
     & )
     & +vas*(s**2+spr**2)*alpha**3*qta**2/(s-spr)*(4d0/9*jintsprtata*mta
     & **2/s**4)
     & +vas*alpha**3*qta**2*spr/(s-spr)*(-32d0/9*jintsprtata*mta**2/s**3
     & )
     & +vas*alpha**3*qta**2/(s-spr)*(16d0/3*jintsprtata*mta**4/s**3)
     & +vas*betasprtata*alpha**3*qta**2*spr/(s-spr)*(-8d0/3*mta**2/s**3)
     & +vaspr*betasprtata*(s**2+spr**2)*alpha**3*qdn**2/spr**2/(s-spr)*(
     & 4d0/3*ln1sdn*mta**2/s**2)
     & +a1sspr*(s+spr)*alpha**3*qdn**2*qta**2/spr*(-2d0/3*jintsprtata*mt
     & a**2/s**3)

      hard = hard*conhc

      return
      end
